/*
Copyright (c) 2022 Honeywell International, Inc. All rights reserved.
This file contains trade secrets of Honeywell International, Inc. No part
may be reproduced or transmitted in any form by any means or for any
purpose without the express written permission of Honeywell.
*/

define(['baja!',
  'nmodule/webEditors/rc/fe/baja/BaseEditor',
  'baja!honIrmControl:ToNormalTimeDelayEnum',
  'bajaux/mixin/subscriberMixIn',
  'jquery',
  'dialogs',
  'Promise',
  'bajaux/util/SaveCommand',
  'hbs!nmodule/honIrmControl/rc/templates/toNormalTimeDelay',
  'lex!honIrmControl'],
  function (      //NOSONAR
    baja,
    BaseEditor,
    ToNormalTimeDelayEnum,
    subscriberMixin,
    $,
    dialogs,
    Promise,
    SaveCommand,
    template,
    lex) {
	
	'use strict';
	
	var honIrmControlLex = lex[0];
	var latestValue;
	
	
	function getToNormalTimeDelaySelect(dom) {									
		return dom.find('#toNormalTimeDelaySelectId');
	}
    function getTimeDelayValueId(dom){
    	return dom.find('#timeDelayValueId');
    }
	function getToNormalTimeDelayTxt(dom) {									
		return  dom.find('#toNormalTimeDelayTxtId');
	}

    /**
    * An editor which helps in editing value
    */
    var ToNormalTimeDelayWidget = function () {   //NOSONAR
      BaseEditor.apply(this, arguments);
      subscriberMixin(this);
      this.getCommandGroup().add(new SaveCommand());
      this.toNormalTimeDelayOptionsObjs = baja.$('honIrmControl:ToNormalTimeDelayEnum');
      this.Enable = this.toNormalTimeDelayOptionsObjs.getEnum().getRange().getOrdinals()[0];
      this.Disable = this.toNormalTimeDelayOptionsObjs.getEnum().getRange().getOrdinals()[1];
      this.toNormalTimeDelayMaxVal =86400; 
      this.toNormalTimeDelayMinVal =0; 
      this.nanValue = "NaN";
    };

    //extend and set up prototype chain
    ToNormalTimeDelayWidget.prototype = Object.create(BaseEditor.prototype);
    ToNormalTimeDelayWidget.prototype.constructor = ToNormalTimeDelayWidget;

    /**
    * Do initial setup of the DOM for the widget. This will set up the DOM's
    * structure and create a space where the editors would go.
    *
    * @param {jQuery} element the DOM element into which to load this widget
    */
    ToNormalTimeDelayWidget.prototype.doInitialize = function (dom) {
      BaseEditor.prototype.doInitialize.call(this, dom);
      var that = this;     
      dom.html(template({
    	  
      }));  
       
      dom.find('select').on('change', function () {
          that.setModified(true);
        });  
      dom.find('input').on('keyup', function (e) {
         if (e.key !== 'Enter' && e.keyCode !== 13){
         	if(!isNaN(this.value)){
		     	latestValue = this.value;
		     }
            that.setModified(true);
         }
        });
    };
    
    /**
    * Load the component
    */
    ToNormalTimeDelayWidget.prototype.doLoad = function (comp) {
  	 var widget = this;
  	 var dom = widget.jq();
 	 loadToNormalTimeDelayContent(comp, widget);
	 dom.on("change", "#toNormalTimeDelaySelectId",widget,function(event){
		     event.preventDefault();
		     changeVisibilityOfToNormalTimeDelayTextField(widget);
		});
		dom.on("change", "#toNormalTimeDelayTxtId",widget,function(event){
	     event.preventDefault();
	     widget.setModified(true);
	});
    };
    
    
    
   function showErrorOnToNormalTimeDelayValidation(widget){ 
	var dom = widget.jq();
    var toNormalTimeDelayOption = parseInt(getToNormalTimeDelaySelect(dom).val(), 2);
    if(toNormalTimeDelayOption === widget.Enable){
   	 var toNormalTimeDelayOptionValueEntered = getToNormalTimeDelayTxt(dom).val();
   	 if(toNormalTimeDelayOptionValueEntered ==='' || isNaN(toNormalTimeDelayOptionValueEntered) ||toNormalTimeDelayOptionValueEntered > widget.toNormalTimeDelayMaxVal || toNormalTimeDelayOptionValueEntered < widget.toNormalTimeDelayMinVal ){
				 dialogs.showOk({
					  title: honIrmControlLex.get('honIrmControlLex.to.normal.time.delay.error.title'),
					  content: honIrmControlLex.get('honIrmControlLex.to.normal.time.delay.limit.error'),
					  private: false
				     })
					  .ok(function () {
					    return true;
					  });
					
				 return true;
			  
		  }
     }
    }
    
    function changeVisibilityOfToNormalTimeDelayTextField(widget){ 
    	 var dom = widget.jq();
	     var toNormalTimeDelayOption = parseInt(getToNormalTimeDelaySelect(dom).val());
	     if(toNormalTimeDelayOption !== widget.Enable){
	     	 getTimeDelayValueId(dom).hide();
	    	 getToNormalTimeDelayTxt(dom).val(widget.nanValue);
	     }else{
	    	 getTimeDelayValueId(dom).show();
	    	 if(latestValue === widget.nanValue){
	    	 	latestValue = widget.toNormalTimeDelayMinVal
	    	 }
	    	 getToNormalTimeDelayTxt(dom).val(latestValue);
	     }
    }
    
    function loadToNormalTimeDelayContent(component, widget){
    	widget.getComplex().getParent().rpc("getToNormalTimeDelayValues").then(function(value) {
    		if(value !== undefined){
    			 var dom = widget.jq();
    			var jsonObj = JSON.parse(value);
    			 var toNormalTimeDelayEnum = jsonObj.toNormalTimeDelayEnum,
    			 toNormalTimeDelayValue = jsonObj.toNormalTimeDelayValue
    			 var toNormalTimeDelayOptionsObj1s = baja.$('honIrmControl:ToNormalTimeDelayEnum');
    			 var toNormalTimeDelayOptionOrdinal = toNormalTimeDelayOptionsObj1s.getEnum().getRange().getOrdinals();
    				var option = '';
    				$("#toNormalTimeDelaySelectId option").remove();
    				for (var i=0;i<toNormalTimeDelayOptionOrdinal.length;i++){
    					var toNormalTimeDelayOption =  toNormalTimeDelayOptionsObj1s.getEnum().getRange().getDisplayTag(toNormalTimeDelayOptionOrdinal[i]);
    					option += '<option value="'+ toNormalTimeDelayOptionOrdinal[i] + '">' + toNormalTimeDelayOption + '</option>';
    				}
    				getToNormalTimeDelaySelect(dom).append(option);
    				getToNormalTimeDelaySelect(dom).val(toNormalTimeDelayEnum.toString());
    				getToNormalTimeDelayTxt(dom).val(toNormalTimeDelayValue);
    				if(toNormalTimeDelayValue === widget.nanValue){
    					getToNormalTimeDelaySelect(dom).val(widget.Disable);
    				}
    				latestValue = getToNormalTimeDelayTxt(dom).val();
    			     if(toNormalTimeDelayEnum !== widget.Enable){
    			    	 getTimeDelayValueId(dom).hide();
    			     }else{
    			    	 getTimeDelayValueId(dom).show();
    			     }
    		}        	    	
        });
    }
    
    /**
     * Detach the event handlers when destroying the widget.
     */
    ToNormalTimeDelayWidget.prototype.doDestroy = function () {
      this.jq().find('input').off();
      this.jq().find('select').off();
    };

    /**
     * Save the user-entered changes to the loaded component.
     *
     * Note that the parameter to this function is the same as that resolved by
     * doRead().
     *
     */
    ToNormalTimeDelayWidget.prototype.doSave = function (readValue, params) {
     	 var widget = this;
     	 var dom = widget.jq();
     	 var isErrorDialogShown = showErrorOnToNormalTimeDelayValidation(widget);
	     if(true === isErrorDialogShown){
	    	 getToNormalTimeDelayTxt(dom).val(latestValue);
	     }
	     else{
	     	saveToNormalTimeDelayContent(readValue, widget);
	     }
     };
       
     function saveToNormalTimeDelayContent(component, widget){
    	 var dom = widget.jq();
    	 var toNormalTimeDelay = { toNormalTimeDelayValue: getToNormalTimeDelayTxt(dom).val()};
    	 var toNormalTimeDelayJSON = JSON.stringify(toNormalTimeDelay);
       widget.getComplex().getParent().rpc("setToNormalTimeDelayValues",toNormalTimeDelayJSON).then(function(value){     	    	
          }).catch(function(err) {
					return Promise.reject(err);
				});
      }
    return ToNormalTimeDelayWidget;
  });
