/*
Copyright (c) 2021 Honeywell International, Inc. All rights reserved.
This file contains trade secrets of Honeywell International, Inc. No part
may be reproduced or transmitted in any form by any means or for any
purpose without the express written permission of Honeywell.
*/
/**
  * Builds a javascript widget that builds property sheet for Ethernet Configuration Slot in IP Configuration
  * @H356559
  */
 
define(['baja!',
  'nmodule/webEditors/rc/fe/baja/BaseEditor', 
  'bajaux/mixin/subscriberMixIn',
  'jquery',
  'bajaux/util/SaveCommand',
  'hbs!nmodule/honIrmConfig/rc/templates/ethernetConfiguration'],
  function (      //NOSONAR,
    baja,
    BaseEditor,
    subscriberMixin,
    $,
    SaveCommand,
    template) {
	
	'use strict';
		
	
	function getIPAddressTypeSelected(dom) {									
		return dom.find('#ipAddressTypeSelectId');
	}
	
	function getEnabledField(dom) {		
		return  dom.find('#enabledTextId');
	}
	
	function getStatusField(dom) {							
		return  dom.find('#statusTextId');
	}
	
	function getFaultCauseField(dom) {							
		return  dom.find('#faultCauseTextId');
	}
    
	function getIpAddressField(dom) {									
		return  dom.find('#ipAddrTextId');
	}
	
	function getSubnetMaskField(dom) {									
		return dom.find('#subnetMaskTextId');
	}
	
	function getDefaultGatewayField(dom) {									
		return dom.find('#defaultGatewayTextId');
	}
	
    /**
    * An editor which helps in editing value
    */
    var EthernetConfigurationWidget = function () {   //NOSONAR
      BaseEditor.apply(this, arguments);
    	//BaseEditor.make(this,arguments);
      subscriberMixin(this);
      this.getCommandGroup().add(new SaveCommand());
      this.ipAddressTypeOptionsObjs = baja.$('honIrmConfig:IPAddressTypeEnum');
      this.dhcp = this.ipAddressTypeOptionsObjs.getEnum().getRange().getOrdinals()[1];
    };

    //extend and set up prototype chain
    EthernetConfigurationWidget.prototype = Object.create(BaseEditor.prototype);
    EthernetConfigurationWidget.prototype.constructor = EthernetConfigurationWidget;

    /**
    * Do initial setup of the DOM for the widget. This will set up the DOM's
    * structure and create a space where the editors would go.
    *
    * @param {jQuery} element the DOM element into which to load this widget
    */
   
    EthernetConfigurationWidget.prototype.doInitialize = function (dom) {
      BaseEditor.prototype.doInitialize.call(this, dom);
      var that = this;      //NOSONAR javascript:S3504
      dom.html(template({
    	  
      })); 
       
      dom.find('select').on('change', function () {
          that.setModified(true);
        });  
      dom.find('input').on('change', function () {
          that.setModified(true);
        });
      dom.find(':text').keydown(function () {
          that.setModified(true);
        });
    };
    
    /**
    * Load the component
    */
    EthernetConfigurationWidget.prototype.doLoad = function (comp) {
  	 var widget = this;
  	 var dom = widget.jq();
 	 loadEthernetConfigurationContent(comp, widget);
	 dom.on("change", "#ipAddressTypeSelectId",widget,function(event){
		     event.preventDefault();
		     changeVisibilityOfEthernetConfigurationFields(widget);
		});
    };
    
	  function changeVisibilityOfEthernetConfigurationFields(widget) {
		  var dom = widget.jq();
		  var ipAddressTypeOption = parseInt(getIPAddressTypeSelected(dom).val());
		  if (ipAddressTypeOption === widget.dhcp) {
			  getIpAddressField(dom).prop("readonly", true);
			  getSubnetMaskField(dom).prop("readonly", true);
			  getDefaultGatewayField(dom).prop("readonly", true);
		  } else {
			  getIpAddressField(dom).prop("readonly", false);
			  getSubnetMaskField(dom).prop("readonly", false);
			  getDefaultGatewayField(dom).prop("readonly", false);
		  }
	  }
    
	  function loadEthernetConfigurationContent(component, widget) {
		  var jsonObj = null;
		  component.getParent().rpc("getEthernetConfigurationValues").then(function(value) {
			  if (value !== undefined) {
				  var dom = widget.jq();
				  jsonObj = JSON.parse(value);
				  var ipAddressTypeEnum = jsonObj.ipAddressTypeEnum;
				  var subnetMaskValue = jsonObj.subnetMaskValue;
				  var ipAddressValue = jsonObj.ipAddressValue;
				  var defaultGatewayValue = jsonObj.defaultGatewayValue;
				  var enabledValue = jsonObj.enabledValue;
				  var statusValue = jsonObj.statusValue;
				  var faultCauseValue = jsonObj.faultCauseValue;
				  var ipAddressTypeOptionsObjs1 = baja.$('honIrmConfig:IPAddressTypeEnum');
				  var ipAddressTypeOptionOrdinal = ipAddressTypeOptionsObjs1.getEnum().getRange().getOrdinals();
				  var option = '';
				  $("#ipAddressTypeSelectId option").remove();
				  for (var i = 0; i < ipAddressTypeOptionOrdinal.length; i++) {
					  var ipAddressTypeOption = ipAddressTypeOptionsObjs1.getEnum().getRange().getDisplayTag(ipAddressTypeOptionOrdinal[i]);
					  option += '<option value="' + ipAddressTypeOptionOrdinal[i] + '">' + ipAddressTypeOption + '</option>';
				  }
				  getIPAddressTypeSelected(dom).append(option);
				  getIPAddressTypeSelected(dom).val(ipAddressTypeEnum.toString());
				  if(Boolean(enabledValue)) {
					getEnabledField(dom).prop("checked", true);
				  } else {
					getEnabledField(dom).prop("checked", false);
				  }
				  getStatusField(dom).val(String(statusValue));
				  getFaultCauseField(dom).val(String(faultCauseValue));
				  getIpAddressField(dom).val(String(ipAddressValue));
				  getSubnetMaskField(dom).val(String(subnetMaskValue));
				  getDefaultGatewayField(dom).val(String(defaultGatewayValue));
				  if (ipAddressTypeEnum === widget.dhcp) {
					  getIpAddressField(dom).prop("readonly", true);
					  getSubnetMaskField(dom).prop("readonly", true);
					  getDefaultGatewayField(dom).prop("readonly", true);
				  } else {
					  getIpAddressField(dom).prop("readonly", false);
					  getSubnetMaskField(dom).prop("readonly", false);
					  getDefaultGatewayField(dom).prop("readonly", false);
				  }
				  getEnabledField(dom).attr('disabled', 'disabled');
				  getEnabledField(dom).attr('readonly', 'readonly');
				  getStatusField(dom).prop("readonly", true);
				  getFaultCauseField(dom).prop("readonly", true);
			  }
		  });
	  }
    
    /**
     * Detach the event handlers when destroying the widget.
     */
    EthernetConfigurationWidget.prototype.doDestroy = function () {
      this.jq().find('input').off();
      this.jq().find('select').off();
    };

    /**
     * Save the user-entered changes to the loaded component.
     *
     * Note that the parameter to this function is the same as that resolved by
     * doRead().
     *
     */
    EthernetConfigurationWidget.prototype.doSave = function (readValue, params) {
     	 var widget = this;
      	 saveEthernetConfigurationContent(readValue, widget);
     };
       
	  function saveEthernetConfigurationContent(component, widget) {
		  var dom = widget.jq();
		  var ethernetConfiguration = { ipAddressTypeEnum: getIPAddressTypeSelected(dom).val(), ipAddressValue: getIpAddressField(dom).val(), subnetMaskValue: getSubnetMaskField(dom).val(), defaultGatewayValue: getDefaultGatewayField(dom).val() };
		  var ethernetConfigurationJSON = JSON.stringify(ethernetConfiguration);
		  component.getParent().rpc("setEthernetConfigurationValues", ethernetConfigurationJSON).then(function(value) {
		  });
		loadEthernetConfigurationContent(component, widget);
	  }
    return EthernetConfigurationWidget;
  });
