/*
Copyright (c) 2022 Honeywell International, Inc. All rights reserved.
This file contains trade secrets of Honeywell International, Inc. No part
may be reproduced or transmitted in any form by any means or for any
purpose without the express written permission of Honeywell.
*/
/**
  * Builds a javascript widget that builds property sheet for WiFi Configuration Slot in IP Configuration
  * @H356559
  */
 
define(['baja!',
  'nmodule/webEditors/rc/fe/baja/BaseEditor', 
  'bajaux/mixin/subscriberMixIn',
  'jquery',
  'bajaux/util/SaveCommand',
  'hbs!nmodule/honIrmConfig/rc/templates/wifiConfiguration'],
  function (      //NOSONAR,
    baja,
    BaseEditor,
    subscriberMixin,
    $,
    SaveCommand,
    template) {
	
	'use strict';
		
	var sub = new baja.Subscriber();
	
	function getWiFiSecurityTypeSelected(dom) {									
		return dom.find('#wifiSecurityTypeSelectId');
	}
	
	function getStatusField(dom) {							
		return  dom.find('#wifiStatusTextId');
	}
	
	function getFaultCauseField(dom) {							
		return  dom.find('#wifiFaultCauseTextId');
	}
    
	function getWiFiSSIDField(dom) {									
		return  dom.find('#wifiSSIDTextId');
	}
	
	function getPasswordField(dom) {									
		return dom.find('#passwordTextId');
	}
	
    /**
    * An editor which helps in editing value
    */
    var WiFiConfigurationWidget = function () {   //NOSONAR
      BaseEditor.apply(this, arguments);
    	//BaseEditor.make(this,arguments);
      subscriberMixin(this);
      this.getCommandGroup().add(new SaveCommand());
      this.wifiSecurityTypeOptionsObjs = baja.$('honIrmConfig:WIFISecurityTypeEnum');
      this.open = this.wifiSecurityTypeOptionsObjs.getEnum().getRange().getOrdinals()[0];
    };

    //extend and set up prototype chain
    WiFiConfigurationWidget.prototype = Object.create(BaseEditor.prototype);
    WiFiConfigurationWidget.prototype.constructor = WiFiConfigurationWidget;

    /**
    * Do initial setup of the DOM for the widget. This will set up the DOM's
    * structure and create a space where the editors would go.
    *
    * @param {jQuery} element the DOM element into which to load this widget
    */
   
    WiFiConfigurationWidget.prototype.doInitialize = function (dom) {
      BaseEditor.prototype.doInitialize.call(this, dom);
      var that = this;      //NOSONAR javascript:S3504
      dom.html(template({
    	  
      })); 
       
      dom.find('select').on('change', function () {
          that.setModified(true);
        });  
      dom.find('input').on('change', function () {
          that.setModified(true);
        });
      dom.find(':text').keydown(function () {
          that.setModified(true);
        });
      dom.find(':password').keydown(function () {
          that.setModified(true);
        });

    };

    /**
    * Load the component
    */
    WiFiConfigurationWidget.prototype.doLoad = function (comp) {
  	 var widget = this;
  	 var dom = widget.jq();
	 sub.attach('changed', function(prop) {
		 if (prop.getName() === 'faultCause') { loadWiFiConfigurationContent(prop.$complex, widget); }
	 });
	 var ord = 'station:|' + comp.getSlotPath();
	 baja.Ord.make(ord).get({ subscriber: sub }).then(loadWiFiConfigurationContent);
 	 loadWiFiConfigurationContent(comp, widget);
	 dom.on("change", "#wifiSecurityTypeSelectId",widget,function(event){
		     event.preventDefault();
		     changeVisibilityOfWiFiConfigurationFields(widget);
		});
    };
    
	  function changeVisibilityOfWiFiConfigurationFields(widget) {
		  var dom = widget.jq();
		  var wifiSecurityTypeOption = parseInt(getWiFiSecurityTypeSelected(dom).val());
		  if (wifiSecurityTypeOption === widget.open) {
			  getPasswordField(dom).prop("readonly", true);
		  } else {
			  getPasswordField(dom).prop("readonly", false);
		  }
	  }
    
	  function loadWiFiConfigurationContent(component, widget) {
		  var jsonObj = null;
		  component.getParent().rpc("getWiFiConfigurationValues").then(function(value) {
			  if (value !== undefined) {
				  var dom = widget.jq();
				  jsonObj = JSON.parse(value);
				  var wifiSecurityTypeEnum = jsonObj.wifiSecurityTypeEnum;
				  var statusValue = jsonObj.statusValue;
				  var faultCauseValue = jsonObj.faultCauseValue;
				  var ssidValue = jsonObj.wifiSSID;
				  var passwordValue = jsonObj.wifiPassword;
				  var wifiSecurityTypeOptionsObjs1 = baja.$('honIrmConfig:WIFISecurityTypeEnum');
				  var wifiSecurityTypeOptionOrdinal = wifiSecurityTypeOptionsObjs1.getEnum().getRange().getOrdinals();
				  var option = '';
				  $("#wifiSecurityTypeSelectId option").remove();
				  for (var i = 0; i < wifiSecurityTypeOptionOrdinal.length; i++) {
					  if (i === 3) {
						  continue;
					  }
					  var wifiSecurityTypeOption = wifiSecurityTypeOptionsObjs1.getEnum().getRange().getDisplayTag(wifiSecurityTypeOptionOrdinal[i]);
					  option += '<option value="' + wifiSecurityTypeOptionOrdinal[i] + '">' + wifiSecurityTypeOption + '</option>';
				  }
				  getWiFiSecurityTypeSelected(dom).append(option);
				  getWiFiSecurityTypeSelected(dom).val(wifiSecurityTypeEnum.toString());
				  getStatusField(dom).val(String(statusValue));
				  getFaultCauseField(dom).val(String(faultCauseValue));
				  getWiFiSSIDField(dom).val(String(ssidValue));
				  getPasswordField(dom).val(String(passwordValue));
				  if (wifiSecurityTypeEnum === widget.open) {
					  getPasswordField(dom).prop("readonly", true);
				  } else {
					  getPasswordField(dom).prop("readonly", false);
				  }
				  getStatusField(dom).prop("readonly", true);
				  getFaultCauseField(dom).prop("readonly", true);
			  }
		  });
	  }
    
    /**
     * Detach the event handlers when destroying the widget.
     */
    WiFiConfigurationWidget.prototype.doDestroy = function () {
	  sub.unsubscribeAll();
      sub.detach();
      this.jq().find('input').off();
      this.jq().find('select').off();
    };

    /**
     * Save the user-entered changes to the loaded component.
     *
     * Note that the parameter to this function is the same as that resolved by
     * doRead().
     *
     */
    WiFiConfigurationWidget.prototype.doSave = function (readValue, params) {
     	 var widget = this;
      	 saveWiFiConfigurationContent(readValue, widget);
     };
       
	  function saveWiFiConfigurationContent(component, widget) {
		  var dom = widget.jq();
		  var wifiConfiguration = { wifiSecurityTypeEnum: getWiFiSecurityTypeSelected(dom).val(), wifiSSID: getWiFiSSIDField(dom).val(), wifiPassword: getPasswordField(dom).val() };
		  var wifiConfigurationJSON = JSON.stringify(wifiConfiguration);
		  component.getParent().rpc("setWiFiConfigurationValues", wifiConfigurationJSON).then(function(value) {
		  });
	  }
    return WiFiConfigurationWidget;
  });
